BodyInit typedef

BodyInit = Object?

Constructor input accepted by body implementations.

Standard detached forms:

On IO, dart:io File values are supported through the platform Blob implementation.

Bodies normalize supported inputs into a detached Blob when possible. Platform implementations may accept additional host-backed inputs before materialization.

Implementation

typedef BodyInit = Object?;