Body class
Detached body implementation.
This is the shared body baseline that web/io implementations align to.
Properties
- bodyUsed → bool
-
no setter
- contentType → String?
-
The body-derived media type, when extracting the body produced one.
final
-
first
→ Future<
Uint8List> -
The first element of this stream.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isBroadcast → bool
-
Whether this stream is a broadcast stream.
no setterinherited
-
isEmpty
→ Future<
bool> -
Whether this stream contains any elements.
no setterinherited
-
last
→ Future<
Uint8List> -
The last element of this stream.
no setterinherited
-
length
→ Future<
int> -
The number of elements in this stream.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
single
→ Future<
Uint8List> -
The single element of this stream.
no setterinherited
- size → int
-
The size in bytes.
no setteroverride
- type → String
-
The media type.
finalinherited
Methods
-
any(
bool test(Uint8List element)) → Future< bool> -
Checks whether
testaccepts any element provided by this stream.inherited -
arrayBuffer(
) → Future< Uint8List> -
Returns all bytes.
override
-
asBroadcastStream(
{void onListen(StreamSubscription< Uint8List> subscription)?, void onCancel(StreamSubscription<Uint8List> subscription)?}) → Stream<Uint8List> -
Returns a multi-subscription stream that produces the same events as this.
inherited
-
asyncExpand<
E> (Stream< E> ? convert(Uint8List event)) → Stream<E> -
Transforms each element into a sequence of asynchronous events.
inherited
-
asyncMap<
E> (FutureOr< E> convert(Uint8List event)) → Stream<E> -
Creates a new stream with each data event of this stream asynchronously
mapped to a new event.
inherited
-
blob(
) → Future< Blob> -
bytes(
) → Future< Uint8List> -
override
-
cast<
R> () → Stream< R> -
Adapt this stream to be a
Stream<R>.inherited -
clone(
) → Body -
contains(
Object? needle) → Future< bool> -
Returns whether
needleoccurs in the elements provided by this stream.inherited -
distinct(
[bool equals(Uint8List previous, Uint8List next)?]) → Stream< Uint8List> -
Skips data events if they are equal to the previous data event.
inherited
-
drain<
E> ([E? futureValue]) → Future< E> -
Discards all data on this stream, but signals when it is done or an error
occurred.
inherited
-
elementAt(
int index) → Future< Uint8List> -
Returns the value of the
indexth data event of this stream.inherited -
every(
bool test(Uint8List element)) → Future< bool> -
Checks whether
testaccepts all elements provided by this stream.inherited -
expand<
S> (Iterable< S> convert(Uint8List element)) → Stream<S> -
Transforms each element of this stream into a sequence of elements.
inherited
-
firstWhere(
bool test(Uint8List element), {Uint8List orElse()?}) → Future< Uint8List> -
Finds the first element of this stream matching
test.inherited -
fold<
S> (S initialValue, S combine(S previous, Uint8List element)) → Future< S> -
Combines a sequence of values by repeatedly applying
combine.inherited -
forEach(
void action(Uint8List element)) → Future< void> -
Executes
actionon each element of this stream.inherited -
handleError(
Function onError, {bool test(dynamic error)?}) → Stream< Uint8List> -
Creates a wrapper Stream that intercepts some errors from this stream.
inherited
-
join(
[String separator = ""]) → Future< String> -
Combines the string representation of elements into a single string.
inherited
-
json<
T> () → Future< T> -
lastWhere(
bool test(Uint8List element), {Uint8List orElse()?}) → Future< Uint8List> -
Finds the last element in this stream matching
test.inherited -
listen(
void onData(Uint8List event)?, {Function? onError, void onDone()?, bool? cancelOnError}) → StreamSubscription< Uint8List> -
Adds a subscription to this stream.
override
-
map<
S> (S convert(Uint8List event)) → Stream< S> -
Transforms each element of this stream into a new stream event.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pipe(
StreamConsumer< Uint8List> streamConsumer) → Future -
Pipes the events of this stream into
streamConsumer.inherited -
reduce(
Uint8List combine(Uint8List previous, Uint8List element)) → Future< Uint8List> -
Combines a sequence of values by repeatedly applying
combine.inherited -
singleWhere(
bool test(Uint8List element), {Uint8List orElse()?}) → Future< Uint8List> -
Finds the single element in this stream matching
test.inherited -
skip(
int count) → Stream< Uint8List> -
Skips the first
countdata events from this stream.inherited -
skipWhile(
bool test(Uint8List element)) → Stream< Uint8List> -
Skip data events from this stream while they are matched by
test.inherited -
slice(
int start, [int? end, String? contentType]) → Blob -
Returns a new
Blockcontaining bytes fromstart(inclusive) toend(exclusive), using Blob-compatible index normalization.override -
stream(
{int chunkSize = _defaultBlobChunkSize}) → Stream< Uint8List> -
Streams bytes in chunks.
override
-
take(
int count) → Stream< Uint8List> -
Provides at most the first
countdata events of this stream.inherited -
takeWhile(
bool test(Uint8List element)) → Stream< Uint8List> -
Forwards data events while
testis successful.inherited -
text(
[Encoding encoding = utf8]) → Future< String> -
Returns UTF-8 decoded text.
override
-
timeout(
Duration timeLimit, {void onTimeout(EventSink< Uint8List> sink)?}) → Stream<Uint8List> -
Creates a new stream with the same events as this stream.
inherited
-
toList(
) → Future< List< Uint8List> > -
Collects all elements of this stream in a List.
inherited
-
toSet(
) → Future< Set< Uint8List> > -
Collects the data of this stream in a Set.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
transform<
S> (StreamTransformer< Uint8List, S> streamTransformer) → Stream<S> -
Applies
streamTransformerto this stream.inherited -
where(
bool test(Uint8List element)) → Stream< Uint8List> -
Creates a new stream from this stream that discards some elements.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited